@@ -12,14 +12,19 @@ def simulate(gg, level, commands, run_pretest=True):
     level._setup()
 
     for command in commands:
+        command = command.strip()
+        if len(command) == 0 or command[0] == '#':
+            continue
+        # Only test if there are commands which change state.
+        if run_pretest:
+            assert not level._test()
+
+        print(f'Calling command: {command}')
         if command.startswith('{create}'):
             filename = command[len('{create} '):].strip()
             write_file(filename)
         elif '^' in command and os.name == 'nt':
             command = command.replace('^', '^^')
-        # Only test if there are commands which change state.
-        if run_pretest:
-            assert not level._test()
         subprocess.call(command, shell=True)
 
     assert level._test()
